Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/gentrie/__init__.py | (no class) | 6 | 0 | 0 | 0 | 0 | 100%
src/gentrie/exceptions.py | ErrorTag | 0 | 0 | 0 | 0 | 0 | 100%
src/gentrie/exceptions.py | TrieTypeError | 2 | 0 | 0 | 0 | 0 | 100%
src/gentrie/exceptions.py | TrieKeyError | 2 | 0 | 0 | 0 | 0 | 100%
src/gentrie/exceptions.py | TrieValueError | 2 | 0 | 0 | 0 | 0 | 100%
src/gentrie/exceptions.py | InvalidTrieKeyTokenError | 0 | 0 | 0 | 0 | 0 | 100%
src/gentrie/exceptions.py | InvalidGeneralizedKeyError | 0 | 0 | 0 | 0 | 0 | 100%
src/gentrie/exceptions.py | DuplicateKeyError | 0 | 0 | 0 | 0 | 0 | 100%
src/gentrie/exceptions.py | (no class) | 23 | 0 | 0 | 0 | 0 | 100%
src/gentrie/nodes.py | Node | 23 | 1 | 0 | 10 | 1 | 94%
src/gentrie/nodes.py | (no class) | 10 | 0 | 2 | 0 | 0 | 100%
src/gentrie/protocols.py | TrieKeyToken | 0 | 0 | 2 | 0 | 0 | 100%
src/gentrie/protocols.py | Hashable | 0 | 0 | 2 | 0 | 0 | 100%
src/gentrie/protocols.py | (no class) | 8 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/__init__.py | GeneralizedTrie | 0 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/__init__.py | (no class) | 8 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/access.py | TrieAccessMixin | 28 | 0 | 0 | 20 | 0 | 100%
src/gentrie/trie/access.py | (no class) | 9 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/base.py | TrieBase | 28 | 0 | 0 | 4 | 1 | 97%
src/gentrie/trie/base.py | (no class) | 11 | 0 | 2 | 0 | 0 | 100%
src/gentrie/trie/collection.py | TrieCollectionMixin | 5 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/collection.py | (no class) | 9 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/mutation.py | TrieMutationMixin | 2 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/mutation.py | (no class) | 7 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/removal.py | TrieRemovalMixin | 28 | 0 | 0 | 12 | 0 | 100%
src/gentrie/trie/removal.py | (no class) | 8 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/storage.py | TrieStorageMixin | 25 | 0 | 0 | 12 | 0 | 100%
src/gentrie/trie/storage.py | (no class) | 11 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/traversal.py | TrieTraversalMixin | 31 | 0 | 0 | 26 | 0 | 100%
src/gentrie/trie/traversal.py | (no class) | 10 | 0 | 0 | 0 | 0 | 100%
src/gentrie/trie/trie_mixins.py | TrieMixinsInterface | 0 | 0 | 12 | 0 | 0 | 100%
src/gentrie/trie/trie_mixins.py | (no class) | 14 | 0 | 0 | 0 | 0 | 100%
src/gentrie/types.py | TrieId | 2 | 0 | 2 | 0 | 0 | 100%
src/gentrie/types.py | TrieEntry | 4 | 0 | 0 | 2 | 0 | 100%
src/gentrie/types.py | (no class) | 21 | 0 | 1 | 0 | 0 | 100%
src/gentrie/validation.py | (no class) | 19 | 0 | 0 | 8 | 0 | 100%
tests/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
tests/gentrie/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
tests/gentrie/test_gentri.py | MockDefaultTrieKeyToken | 2 | 0 | 0 | 0 | 0 | 100%
tests/gentrie/test_gentri.py | MockContentAwareTrieKeyToken | 4 | 0 | 0 | 0 | 0 | 100%
tests/gentrie/test_gentri.py | TestGeneralizedTrie | 342 | 1 | 0 | 8 | 1 | 99%
tests/gentrie/test_gentri.py | (no class) | 106 | 0 | 2 | 0 | 0 | 100%
Total |  | 810 | 2 | 25 | 102 | 3 | 99%

No items found using the specified filter.